@@ -1,4 +1,5 @@
 #include "captchasettingstab.h"
+#include "../shared/decaptchaaccountsmodel.h"
 #include "../shared/settings.h"
 #include <QTreeView>
 #include <QPushButton>
@@ -6,7 +7,6 @@
 #include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
-#include <QFileDialog>
 #include <QMenu>
 
 CaptchaSettingsTab::CaptchaSettingsTab(QWidget *parent) :
