@@ -1,9 +1,9 @@
 #ifndef CAPTCHASETTINGSTAB_H
 #define CAPTCHASETTINGSTAB_H
 
-#include "../shared/decaptchaaccountsmodel.h"
 #include <QWidget>
 
+class DecaptchaAccountsModel;
 class QTreeView;
 class QPushButton;
 class QLineEdit;
