@@ -52,7 +52,7 @@ MainWindow::MainWindow(QWidget *parent) :
     m_optionsMenu(new QMenu(m_optionsButton)),
     m_concurrentMenu(m_optionsMenu->addMenu(tr("Maximum concurrent downloads"))),
     m_concurrentGroup(new QActionGroup(this)),
-    m_connectionsMenu(m_optionsMenu->addMenu(tr("Maximum connections per transfer"))),
+    m_connectionsMenu(m_optionsMenu->addMenu(tr("Maximum connections per download"))),
     m_connectionsGroup(new QActionGroup(this)),
     m_rateLimitMenu(m_optionsMenu->addMenu(tr("Maximum download speed"))),
     m_rateLimitGroup(new QActionGroup(this)),
