@@ -86,7 +86,7 @@ MainWindow::MainWindow(QWidget *parent) :
     m_nextActionGroup(new QActionGroup(this)),
     m_concurrentMenu(m_optionsMenu->addMenu(tr("Concurrent downloads"))),
     m_concurrentGroup(new QActionGroup(this)),
-    m_connectionsMenu(m_optionsMenu->addMenu(tr("Connections per transfer"))),
+    m_connectionsMenu(m_optionsMenu->addMenu(tr("Connections per download"))),
     m_connectionsGroup(new QActionGroup(this)),
     m_rateLimitMenu(m_optionsMenu->addMenu(tr("Maximum download speed"))),
     m_rateLimitGroup(new QActionGroup(this)),
