@@ -906,6 +906,15 @@ void Transfer::queue() {
 }
 
 void Transfer::start() {
+    switch(this->status()) {
+    case Transfers::Paused:
+    case Transfers::Failed:
+    case Transfers::Queued:
+	break;
+    default:
+	return;
+    }
+
     if (!m_nam) {
         m_nam = NetworkAccessManager::create();
     }
@@ -947,6 +956,7 @@ void Transfer::pause() {
     switch (this->status()) {
     case Transfers::Extracting:
     case Transfers::Converting:
+    case Transfers::Failed:
         return;
     case Transfers::Downloading:
         foreach (Connection *connection, m_connections) {
@@ -1000,8 +1010,14 @@ void Transfer::onServicePluginStatusChanged(ServicePlugin::Status status) {
         this->onCaptchaRequired();
         return;
     case ServicePlugin::Ready:
-        this->setStatus(Transfers::Queued);
-        return;
+	switch (this->status()) {
+	case Transfers::ShortWait:
+	    this->start();
+	    return;
+        default:
+            this->setStatus(Transfers::Queued);
+            return;
+	}
     }
 }
 
