@@ -1,11 +1,9 @@
 #include "transfermodel.h"
 #include "transfer.h"
-#include "database.h"
 #include "storage.h"
 #include "settings.h"
 #include "urlchecker.h"
 #include "utils.h"
-#include <QDateTime>
 #include <QTimer>
 #include <QCoreApplication>
 
