@@ -20,6 +20,9 @@ class TransferModel : public QAbstractItemModel
     Q_PROPERTY(Transfers::Status statusFilter
                READ statusFilter
                WRITE setStatusFilter)
+    Q_PROPERTY(Transfers::Action nextAction
+               READ nextAction
+               WRITE setNextAction)
     Q_PROPERTY(int totalDownloadSpeed
                READ totalDownloadSpeed
                NOTIFY totalDownloadSpeedChanged)
@@ -28,8 +31,6 @@ class TransferModel : public QAbstractItemModel
                NOTIFY activeTransfersChanged)
 
 public:
-    ~TransferModel();
-
 #if (QT_VERSION >= 0x050000) || (QT_VERSION < 0x040600)
     QHash<int, QByteArray> roleNames() const;
 #endif
@@ -64,6 +65,8 @@ public:
     QString searchQuery() const;
     Transfers::Status statusFilter() const;
 
+    Transfers::Action nextAction() const;
+
     int totalDownloadSpeed() const;
 
     int activeTransfers() const;
@@ -74,6 +77,8 @@ public slots:
     void setSearchQuery(const QString &query);
     void setStatusFilter(Transfers::Status status);
 
+    void setNextAction(Transfers::Action action);
+
     void addTransfer(const QUrl &url, const QString &service, const QString &fileName);
 
     bool start();
@@ -87,9 +92,10 @@ public slots:
 
 private:
     TransferModel();
+    ~TransferModel();
 
     void filter();
-    QString generateTransferId(QString seedFileName) const;
+
     void getNextTransfers();
 
     void addActiveTransfer(Transfer *transfer);
@@ -97,9 +103,14 @@ private:
 
 private slots:
     void startNextTransfers();
+#ifdef QML_USER_INTERFACE
+    void onTransferSpeedChanged();
+#else
     void onTransferDataChanged(int role);
+#endif
     void onTransferStatusChanged(Transfers::Status status);
     void onMaximumConcurrentTransfersChanged(int oldMaximum, int newMaximum);
+    void storeAndDeleteTransfers();
     void onTransfersRestored(const QList<Transfer*> &transfers);
 
 signals:
@@ -116,6 +127,7 @@ private:
     QList<Transfer*> m_filteredTransfers;
     QString m_searchQuery;
     Transfers::Status m_statusFilter;
+    Transfers::Action m_nextAction;
     QHash<int, QByteArray> m_roleNames;
 };
 
