@@ -78,7 +78,7 @@ void FileFactory::checkUrlIsValid() {
     }
 
     QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-    QRegExp re("http://\\w+.filefactory.com/dl/[^'\"]+");
+    QRegExp re("http://\\w\\d+.filefactory.com/get/\\w/[^'\"]+");
 
     if ((!redirect.isEmpty()) && (re.indexIn(redirect) == -1)) {
         if (!redirect.startsWith("http://")) {
@@ -95,7 +95,7 @@ void FileFactory::checkUrlIsValid() {
             emit urlChecked(false);
         }
         else {
-            QString fileName = response.section("<title>", 1, 1).section(" - download", 0, 0);
+            QString fileName = response.section("file_name=", 1, 1).section('&', 0, 0);
 
             if (fileName.isEmpty()) {
                 emit urlChecked(false);
@@ -132,7 +132,7 @@ void FileFactory::onWebPageDownloaded() {
         return;
     }
 
-    QRegExp re("http://\\w+.filefactory.com/dl/[^'\"]+");
+    QRegExp re("http://\\w\\d+.filefactory.com/get/\\w/[^'\"]+");
     QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
 
     if (re.indexIn(redirect) == 0) {
@@ -147,9 +147,18 @@ void FileFactory::onWebPageDownloaded() {
         QString response(reply->readAll().simplified());
 
         if (re.indexIn(response) >= 0) {
-            QNetworkRequest request;
-            request.setUrl(QUrl(re.cap()));
-            emit downloadRequestReady(request);
+            m_url = QUrl(re.cap());
+            int secs = response.section("data-delay=\"", 1, 1).section('"', 0, 0).toInt();
+
+            if (secs > 0) {
+                this->startWait(secs * 1000);
+                
+            }
+            else {
+                this->startWait(60000);
+            }
+
+            this->connect(this, SIGNAL(waitFinished()), this, SLOT(onWaitFinished()));
         }
         else if (response.contains(QRegExp("file is no longer available|file has been deleted"))) {
             emit error(NotFound);
@@ -229,26 +238,22 @@ void FileFactory::checkDownloadPage() {
     }
 
     QString response(reply->readAll());
-    QRegExp re("http://\\w+.filefactory.com/dl/[^'\"]+");
+    QRegExp re("http://\\w\\d+.filefactory.com/get/\\w/[^'\"]+");
 
     if (re.indexIn(response) >= 0) {
         m_url = QUrl(re.cap());
 
-        if (m_url.isValid()) {
-            int secs = response.section("id=\"startWait\" value=\"", 1, 1).section('"', 0, 0).toInt();
+        int secs = response.section("data-delay=\"", 1, 1).section('"', 0, 0).toInt();
 
-            if (secs > 0) {
-                this->startWait(secs * 1000);
-            }
-            else {
-                this->startWait(60000);
-            }
-
-            this->connect(this, SIGNAL(waitFinished()), this, SLOT(onWaitFinished()));
+        if (secs > 0) {
+            this->startWait(secs * 1000);
+            
         }
         else {
-            emit error(UnknownError);
+            this->startWait(60000);
         }
+
+        this->connect(this, SIGNAL(waitFinished()), this, SLOT(onWaitFinished()));
     }
     else {
         emit error(UnknownError);
